@@ -44,8 +44,8 @@ void DummyAI::setShips()
             Coord c(rand() % m_sea->size().x, rand() % m_sea->size().y);
             Ship::Direction dir = rand() % 2 == 0 ? Ship::LEFT_TO_RIGHT : Ship::TOP_DOWN;
             if (m_sea->canAddShip(m_player, c, i, dir)) {
-                ship = new Ship(i, dir);
-                m_sea->add(m_player, c, ship);
+                ship = new Ship(i, dir, c);
+                m_sea->add(m_player, ship);
             }
         }
     }
